Welcome to berserk's documentation!
======================================

.. image:: https://img.shields.io/pypi/v/berserk.svg
        :target: https://pypi.python.org/pypi/berserk
        :alt: Available on PyPI

.. image:: https://img.shields.io/travis/rhgrant10/berserk.svg
        :target: https://travis-ci.org/rhgrant10/berserk
        :alt: Continuous Integration

.. image:: https://codecov.io/gh/rhgrant10/tsplib95/branch/master/graph/badge.svg
        :target: https://codecov.io/gh/rhgrant10/tsplib95
        :alt: Code Coverage

.. image:: https://readthedocs.org/projects/berserk/badge/?version=latest
        :target: https://berserk.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


Python client for the `Lichess API`_.

.. _Lichess API: https://lichess.org/api

----

.. toctree::
   :maxdepth: 4

   readme
   installation
   usage
   api
   contributing
   authors
   history


Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
